@@ -14,14 +14,14 @@ func failedToolResponse(errorMessage string) string {
 }
 
 func printToolMessage(message string) {
-	fmt.Print(styles.AGENT_QUESTION(message) + "\n")
+	fmt.Print(gline.RESET_CURSOR_COLUMN + styles.AGENT_QUESTION(message) + "\n")
 }
 
-func userConfirmation(logger *zap.Logger, question string, explanation string) string {
+var userConfirmation = func(logger *zap.Logger, question string, explanation string) string {
 	prompt :=
 		styles.AGENT_QUESTION(question + " (y/N/freeform reply) ")
 
-	line, err := gline.Gline(prompt, []string{}, explanation, nil, nil, logger, gline.NewOptions())
+	line, err := gline.Gline(prompt, []string{}, explanation, nil, nil, nil, logger, gline.NewOptions())
 	if err != nil {
 		return "no"
 	}
