@@ -3,5 +3,5 @@ package rag
 type ContextRetriever interface {
 	Name() string
 
-	GetContext(options ContextRetrievalOptions) (string, error)
+	GetContext() (string, error)
 }
