@@ -4,7 +4,6 @@ import (
 	"fmt"
 
 	"github.com/atinylittleshell/gsh/internal/environment"
-	"github.com/atinylittleshell/gsh/internal/rag"
 	"mvdan.cc/sh/v3/interp"
 )
 
@@ -16,6 +15,6 @@ func (r WorkingDirectoryContextRetriever) Name() string {
 	return "working_directory"
 }
 
-func (r WorkingDirectoryContextRetriever) GetContext(options rag.ContextRetrievalOptions) (string, error) {
+func (r WorkingDirectoryContextRetriever) GetContext() (string, error) {
 	return fmt.Sprintf("<working_dir>%s</working_dir>", environment.GetPwd(r.Runner)), nil
 }
