@@ -1,31 +1,31 @@
 package retrievers
 
 import (
+	"context"
 	"fmt"
 	"strings"
 
 	"github.com/atinylittleshell/gsh/internal/bash"
-	"github.com/atinylittleshell/gsh/internal/rag"
 	"go.uber.org/zap"
 	"mvdan.cc/sh/v3/interp"
 )
 
-type GitContextRetriever struct {
+type GitStatusContextRetriever struct {
 	Runner *interp.Runner
 	Logger *zap.Logger
 }
 
-func (r GitContextRetriever) Name() string {
-	return "git"
+func (r GitStatusContextRetriever) Name() string {
+	return "git_status"
 }
 
-func (r GitContextRetriever) GetContext(options rag.ContextRetrievalOptions) (string, error) {
-	revParseOut, _, err := bash.RunBashCommandInSubShell(r.Runner, "git rev-parse --show-toplevel")
+func (r GitStatusContextRetriever) GetContext() (string, error) {
+	revParseOut, _, err := bash.RunBashCommandInSubShell(context.Background(), r.Runner, "git rev-parse --show-toplevel")
 	if err != nil {
 		r.Logger.Debug("error running `git rev-parse --show-toplevel`", zap.Error(err))
-		return "", nil
+		return "<git_status>not in a git repository</git_status>", nil
 	}
-	statusOut, _, err := bash.RunBashCommandInSubShell(r.Runner, "git status")
+	statusOut, _, err := bash.RunBashCommandInSubShell(context.Background(), r.Runner, "git status")
 	if err != nil {
 		r.Logger.Debug("error running `git status`", zap.Error(err))
 		return "", nil
