@@ -4,7 +4,6 @@ import (
 	"fmt"
 	"runtime"
 
-	"github.com/atinylittleshell/gsh/internal/rag"
 	"mvdan.cc/sh/v3/interp"
 )
 
@@ -16,7 +15,7 @@ func (r SystemInfoContextRetriever) Name() string {
 	return "system_info"
 }
 
-func (r SystemInfoContextRetriever) GetContext(options rag.ContextRetrievalOptions) (string, error) {
+func (r SystemInfoContextRetriever) GetContext() (string, error) {
 	osName := runtime.GOOS
 	arch := runtime.GOARCH
 	return fmt.Sprintf("<system_info>OS: %s, Arch: %s</system_info>", osName, arch), nil
