@@ -11,12 +11,18 @@ import (
 
 type LLMModelType string
 
+type LLMModelConfig struct {
+	ModelId           string
+	Temperature       *float64
+	ParallelToolCalls *bool
+}
+
 const (
 	FastModel LLMModelType = "FAST"
 	SlowModel LLMModelType = "SLOW"
 )
 
-func GetLLMClient(runner *interp.Runner, modelType LLMModelType) (*openai.Client, string, float32) {
+func GetLLMClient(runner *interp.Runner, modelType LLMModelType) (*openai.Client, LLMModelConfig) {
 	varPrefix := "GSH_" + string(modelType) + "_MODEL_"
 
 	apiKey := runner.Vars[varPrefix+"API_KEY"].String()
@@ -31,9 +37,23 @@ func GetLLMClient(runner *interp.Runner, modelType LLMModelType) (*openai.Client
 	if modelId == "" {
 		modelId = "qwen2.5"
 	}
-	temperature, err := strconv.ParseFloat(varPrefix+runner.Vars["TEMPERATURE"].String(), 32)
-	if err != nil {
-		temperature = 0.1
+
+	var temperature *float64
+	temperatureString := runner.Vars[varPrefix+"TEMPERATURE"].String()
+	if temperatureString != "" {
+		temperatureValue, err := strconv.ParseFloat(temperatureString, 32)
+		if err == nil {
+			temperature = &temperatureValue
+		}
+	}
+
+	var parallelToolCalls *bool
+	parallelToolCallsString := runner.Vars[varPrefix+"PARALLEL_TOOL_CALLS"].String()
+	if parallelToolCallsString != "" {
+		parallelToolCallsValue, err := strconv.ParseBool(parallelToolCallsString)
+		if err == nil {
+			parallelToolCalls = &parallelToolCallsValue
+		}
 	}
 
 	var headers map[string]string
@@ -49,5 +69,9 @@ func GetLLMClient(runner *interp.Runner, modelType LLMModelType) (*openai.Client
 	llmClientConfig.BaseURL = baseURL
 	llmClientConfig.HTTPClient = NewLLMHttpClient(headers)
 
-	return openai.NewClientWithConfig(llmClientConfig), modelId, float32(temperature)
+	return openai.NewClientWithConfig(llmClientConfig), LLMModelConfig{
+		ModelId:           modelId,
+		Temperature:       temperature,
+		ParallelToolCalls: parallelToolCalls,
+	}
 }
